"""Initialize the SMHI package."""

from smhi.smhi_lib import Smhi, SmhiAPIBase, SmhiForecast

__title__ = "SMHI"
__version__ = "1.0.19"
__author__ = "helto4real"
__license__ = "MIT"

__all__ = ["Smhi", "SmhiAPIBase", "SmhiForecast"]
